<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl" version="2.0">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>Version %1</source>
        <translation>Wersja %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 jest wolnym oprogramowaniem, ale jego rozwój zabiera cenny czas.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Proszę o &lt;a href=&apos;%1&apos;&gt;wpłatę&lt;/a&gt; , aby wesprzeć ciągłe rozwijanie %2.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Wydany na zasadach &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp; Zamknij</translation>
    </message>
    <message>
        <source>About</source>
        <translation>O programie</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>Wszystko, co zawsze chcieliście wiedzieć o %1, a baliście się zapytać</translation>
    </message>
    <message>
        <source>You may want to try my other apps as well:</source>
        <translation>Być może chciałbyś wypróbować moje inne aplikacje:</translation>
    </message>
    <message>
        <source>%1, a YouTube app</source>
        <translation>%1, aplikacja YouTube</translation>
    </message>
    <message>
        <source>%1, a YouTube music player</source>
        <translation>%1, odtwarzacz muzyki YouTube</translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation>Przetłumacz %1 na twój język ojczysty używając %2</translation>
    </message>
    <message>
        <source>Licensed to: %1</source>
        <translation>Licencjonowane dla: %1</translation>
    </message>
</context>
<context>
    <name>ActivationDialog</name>
    <message>
        <source>Enter your License Details</source>
        <translation>Wpisz szczegóły Twojej licencji</translation>
    </message>
    <message>
        <source>&amp;Email:</source>
        <translation>&amp;Email:</translation>
    </message>
    <message>
        <source>&amp;Code:</source>
        <translation>&amp;Kod:</translation>
    </message>
</context>
<context>
    <name>ActivationView</name>
    <message>
        <source>Please license %1</source>
        <translation>Proszę licencjonować  %1</translation>
    </message>
    <message>
        <source>This demo has expired.</source>
        <translation>To demo wygasło.</translation>
    </message>
    <message>
        <source>Without a license, the application will expire in %1 days.</source>
        <translation>Bez licencji ta aplikacja wygaśnie za %1 dni.</translation>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>Przez zakup pełnej wersji wesprzesz również ciężką pracę, którą włożyłem w stworzenie %1.</translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation>Użyj Dema</translation>
    </message>
    <message>
        <source>Enter License</source>
        <translation>Wprowadź Licencję</translation>
    </message>
    <message>
        <source>Buy License</source>
        <translation>Kup Licencję</translation>
    </message>
    <message>
        <source>The full version allows you to add more than %1 tracks to the playlist and listen to your music without interruptions.</source>
        <translation>Pełna wersja pozwala na dodanie więcej niż %1 utworów do playlisty oraz słuchanie muzyki bez przerw.</translation>
    </message>
</context>
<context>
    <name>AlbumInfo</name>
    <message>
        <source>Buy on %1</source>
        <translation>Kup na %1</translation>
    </message>
    <message>
        <source>Read more</source>
        <translation>Czytaj więcej</translation>
    </message>
</context>
<context>
    <name>AlbumListView</name>
    <message>
        <source>Artist</source>
        <translation>Artysta</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Tytuł</translation>
    </message>
    <message>
        <source>Year</source>
        <translation>Rok</translation>
    </message>
    <message>
        <source>Popularity</source>
        <translation>Popularność</translation>
    </message>
    <message>
        <source>Reversed Order</source>
        <translation>Odwrócona kolejność</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>Sortuj według</translation>
    </message>
</context>
<context>
    <name>ArtistInfo</name>
    <message>
        <source>Read more</source>
        <translation>Czytaj więcej</translation>
    </message>
</context>
<context>
    <name>ArtistListView</name>
    <message>
        <source>Track Count</source>
        <translation>Ilość utworów</translation>
    </message>
    <message>
        <source>Album Count</source>
        <translation>Ilość albumów</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nazwa</translation>
    </message>
    <message>
        <source>Year</source>
        <translation>Rok</translation>
    </message>
    <message>
        <source>Popularity</source>
        <translation>Popularność</translation>
    </message>
    <message>
        <source>Reversed Order</source>
        <translation>Odwrócona kolejność</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>Sortuj według</translation>
    </message>
</context>
<context>
    <name>BreadcrumbWidget</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Wstecz</translation>
    </message>
    <message>
        <source>Go back</source>
        <translation>Powrót</translation>
    </message>
</context>
<context>
    <name>ChooseFolderView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Witaj w &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>%1 needs to scan your music collection.</source>
        <translation>%1 musi przeskanować twoją kolekcję muzyczną.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Use iTunes collection</source>
        <translation>Użyj biblioteki iTunes</translation>
    </message>
    <message>
        <source>Use %1</source>
        <translation>Użyj %1</translation>
    </message>
    <message>
        <source>Choose a folder...</source>
        <translation>Wybierz folder...</translation>
    </message>
    <message>
        <source>%1 will connect to the Last.fm web services and pass artist names and album titles in order to fetch covert art, biographies and much more.</source>
        <translation>%1 będzie łączyć się z usługami internetowymi Last.fm i przesyłać nazwy wykonawców i tytuły albumów, aby pobierać okładki, biografie i wiele więcej.</translation>
    </message>
    <message>
        <source>If you have privacy concerns about this you can quit now.</source>
        <translation>Jeśli masz obawy związane z prywatnością, możesz zrezygnować.</translation>
    </message>
    <message>
        <source>Where&apos;s your music collection?</source>
        <translation>Gdzie jest twoja kolekcja muzyczna?</translation>
    </message>
    <message>
        <source>Select the location of your music collection.</source>
        <translation>Wybierz lokalizację swojej kolekcji muzycznej.</translation>
    </message>
    <message>
        <source>Locate your collection</source>
        <translation>Zlokalizuj swoją kolekcję</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Wyczyść</translation>
    </message>
</context>
<context>
    <name>CollectionScanner</name>
    <message>
        <source>A scanning task is already running</source>
        <translation>Skanowanie jest już uruchomione</translation>
    </message>
</context>
<context>
    <name>CollectionScannerView</name>
    <message>
        <source>%1 is scanning your music collection.</source>
        <translation>%1 skanuję twoją kolekcję muzyczną.</translation>
    </message>
    <message>
        <source>%1 is using &lt;a href=&apos;%2&apos;&gt;%3&lt;/a&gt; to catalog your music.</source>
        <translation>%1 używa &lt;a href=&apos;%2&apos;&gt;%3&lt;/a&gt; do skatalogowania twojej muzyki.</translation>
    </message>
    <message>
        <source>This will take time depending on your collection size and network speed.</source>
        <translation>To zajmie trochę czasu w zależności od wielkości kolekcji i szybkości łącza.</translation>
    </message>
    <message>
        <source>Go grab a coffee</source>
        <translation>Zrób sobie przerwę na kawę.</translation>
    </message>
</context>
<context>
    <name>DownloadWidget</name>
    <message>
        <source>Downloading update...</source>
        <translation>Ściąganie aktualizacji...</translation>
    </message>
</context>
<context>
    <name>DropArea</name>
    <message>
        <source>Drop here to append to the playlist</source>
        <translation>Upuść tutaj, aby dołączyć do listy odtwarzania</translation>
    </message>
</context>
<context>
    <name>FinderWidget</name>
    <message>
        <source>Artists</source>
        <translation>Wykonawcy</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Albumy</translation>
    </message>
    <message>
        <source>Folders</source>
        <translation>Foldery</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>Odtwarzaj</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pauza</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Odtwarzaj/Pauza</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Zatrzymaj</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>Zatrzymaj odtwarzanie po bieżącym utworze</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>Następny utwór</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Poprzedni utwór</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>Zwiększ głośność</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>Zmniejsz głośność</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Wycisz</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>Przewiń do przodu</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>Przewiń do tyłu</translation>
    </message>
</context>
<context>
    <name>LastFm</name>
    <message>
        <source>Authentication failed</source>
        <translation>Autoryzacja nie powiodła się</translation>
    </message>
</context>
<context>
    <name>LastFmLoginDialog</name>
    <message>
        <source>Log in to %1</source>
        <translation>Zaloguj do %1</translation>
    </message>
    <message>
        <source>&amp;Username:</source>
        <translation>&amp;Nazwa użytkownika:</translation>
    </message>
    <message>
        <source>&amp;Password:</source>
        <translation>&amp;Hasło:</translation>
    </message>
    <message>
        <source>Signup for a %1 account</source>
        <translation>Załóż konto dla %1</translation>
    </message>
    <message>
        <source>Forgot your &lt;a href=&apos;%1&apos;&gt;username&lt;/a&gt; or &lt;a href=&apos;%2&apos;&gt;password&lt;/a&gt;?</source>
        <translation>Zapomniałeś &lt;a href=&apos;%1&apos;&gt;nazwę użytkownika&lt;/a&gt; albo &lt;a href=&apos;%2&apos;&gt;hasło&lt;/a&gt;?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Wstecz</translation>
    </message>
    <message>
        <source>Go to the previous view</source>
        <translation>Powrót do poprzedniego widoku</translation>
    </message>
    <message>
        <source>&amp;Info</source>
        <translation>&amp;Informacje</translation>
    </message>
    <message>
        <source>Show information about the current track</source>
        <translation>Wyświetl informacje o bieżącym utworze</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>&amp;Poprzedni</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>Powrót do poprzedniego utworu</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation>&amp;Następny</translation>
    </message>
    <message>
        <source>Skip to the next track</source>
        <translation>Przejście do następnego utworu</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Odtwarzaj</translation>
    </message>
    <message>
        <source>Start playback</source>
        <translation>Rozpocznij odtwarzanie</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Pełny ekran</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Włącz tryb pełnoekranowy</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Usuń</translation>
    </message>
    <message>
        <source>Remove the selected tracks from the playlist</source>
        <translation>Usuń wybrane utwory z listy odtwarzania</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Przesuń &amp;w górę</translation>
    </message>
    <message>
        <source>Move up the selected tracks in the playlist</source>
        <translation>Przesuń wybrane utwory w górę na liście odtwarzania</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Przesuń &amp;w dół</translation>
    </message>
    <message>
        <source>Move down the selected tracks in the playlist</source>
        <translation>Przesuń wybrane utwory w dół na liście odtwarzania</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Zamknij</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Do widzenia</translation>
    </message>
    <message>
        <source>&amp;Change collection folder...</source>
        <translation>&amp;Zmień folder kolekcji...</translation>
    </message>
    <message>
        <source>Choose a different music collection folder</source>
        <translation>Wybierz inny folder kolekcji</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>&amp;Strona internetowa</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 w Internecie</translation>
    </message>
    <message>
        <source>Make a &amp;donation</source>
        <translation>Dokonaj &amp;wpłaty</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Prosimy o wspieranie dalszego rozwijania %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;O</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Informacje o %1</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>&amp;Wyczyść</translation>
    </message>
    <message>
        <source>Remove all tracks from the playlist</source>
        <translation>Usuń wszystkie utwory z listy odtwarzania</translation>
    </message>
    <message>
        <source>&amp;Shuffle</source>
        <translation>&amp;Pomieszaj</translation>
    </message>
    <message>
        <source>Random playlist mode</source>
        <translation>Losowa lista odtwarzania</translation>
    </message>
    <message>
        <source>&amp;Repeat</source>
        <translation>&amp;Powtórz</translation>
    </message>
    <message>
        <source>Play first song again after all songs are played</source>
        <translation>Odtwarzaj pierwszą piosenkę ponownie po zakończeniu listy odtwarzania</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Wycisz</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Aplikacja</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>&amp;Odtwarzanie</translation>
    </message>
    <message>
        <source>Play&amp;list</source>
        <translation>&amp;Lista odtwarzania</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Widok</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Pomoc</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Wciśnij %1, aby zwiększyć głośność, %2, aby ją zmniejszyć</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Otwieranie %1</translation>
    </message>
    <message>
        <source>Updating collection...</source>
        <translation>Aktualizacja kolekcji...</translation>
    </message>
    <message>
        <source>Updating collection - %1%</source>
        <translation>Aktualizacja kolekcji - %1%</translation>
    </message>
    <message>
        <source>Collection updated</source>
        <translation>Kolekcja zaktualizowana</translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation>Błąd krytyczny: %1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Błąd: %1</translation>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation>Opuść &amp;tryb pełnoekranowy</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Pozostały czas: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Poziom głośności %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Dźwięk wyciszony</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Dźwięk włączony</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Pobierz pełną wersję</translation>
    </message>
    <message>
        <source>%1 version %2 is now available.</source>
        <translation>%1 wersja %2 jest teraz dostępna.</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Przypomnij później</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Aktualizuj</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Okno</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp;Minimalizuj</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zamknij</translation>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation>Kup %1</translation>
    </message>
    <message>
        <source>&amp;Stop After This Track</source>
        <translation>&amp;Zatrzymaj po tym tytule</translation>
    </message>
    <message>
        <source>&amp;Scrobbling</source>
        <translation>&amp;Skroblowanie</translation>
    </message>
    <message>
        <source>Send played tracks titles to %1</source>
        <translation>Wyślij odsłuchane tytuły do %1</translation>
    </message>
    <message>
        <source>&amp;Log Out from %1</source>
        <translation>&amp;Wyloguj z %1</translation>
    </message>
    <message>
        <source>&amp;Report an Issue...</source>
        <translation>&amp;Zgłoś problem...</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Szukaj</translation>
    </message>
    <message>
        <source>%1 finished scanning your music collection</source>
        <translation>%1 zakończono przeszukiwanie twojej kolekcji muzyki</translation>
    </message>
    <message>
        <source>&amp;Love %1? Rate it!</source>
        <translation>&amp;Kochasz %1? Oceń to!</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Drop items here</source>
        <translation>Upuść tutaj</translation>
    </message>
    <message>
        <source>Playlist finished</source>
        <translation>Koniec listy odtwarzania</translation>
    </message>
    <message>
        <source>This is just the demo version of %1.</source>
        <translation>To jest jedynie wersja demonstracyjna %1.</translation>
    </message>
    <message>
        <source>It allows you to play a few tracks so you can test the application and see if it works for you.</source>
        <translation>Pozwala na odtwarzanie kilku utworów, abyś mógł przetestować aplikację i sprawdzić, czy ci odpowiada.</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Kontynuuj</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Pobierz pełną wersję</translation>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>Nowa wersja %1 jest dostępna!</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2 jest już dostępny, Ty masz %3.</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>Czy chcesz to teraz pobrać?</translation>
    </message>
    <message>
        <source>Skip This Version</source>
        <translation>Pomiń Tą Wersję</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>Przypomnij Mi Później</translation>
    </message>
    <message>
        <source>Install Update</source>
        <translation>Zainstaluj aktualizację</translation>
    </message>
</context>
<context>
    <name>PasteLineEdit</name>
    <message>
        <source>Paste</source>
        <translation>Wklej</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>This demo is limited to only %1 tracks in the playlist.</source>
        <translation>Ta wersja demo jest ograniczone do tylko %1 tytułów na liście odtwarzania.</translation>
    </message>
</context>
<context>
    <name>PlaylistView</name>
    <message>
        <source>Playlist is empty</source>
        <translation>Lista odtwarzania jest pusta</translation>
    </message>
    <message>
        <source>%1 tracks - Total length is %2</source>
        <translation>%1 utworów - Całkowita długość wynosi %2</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Szukaj</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Your search had no results.</source>
        <translation>Twoje wyszukiwanie nie przyniosło rezultatów.</translation>
    </message>
</context>
<context>
    <name>TrackListView</name>
    <message>
        <source>Tracks</source>
        <translation>Utwory</translation>
    </message>
</context>
</TS>